"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseGoModGraph = void 0;
const dep_graph_1 = require("@snyk/dep-graph");
const types_1 = require("../types");
const GO_MODULES = 'gomodules';
function parseGoModGraphLine(line) {
    return line
        .trim()
        .split(/\s/)
        .map((item) => item.split('@'));
}
function parseGoModGraph(goModGraphOutput, projectName, projectVersion = types_1.DEFAULT_INITIAL_VERSION) {
    const rootPkgInfo = { name: projectName, version: projectVersion };
    const depGraph = new dep_graph_1.DepGraphBuilder({ name: GO_MODULES }, rootPkgInfo);
    for (const line of goModGraphOutput.trim().split('\n')) {
        const [[parentName, parentVersion = types_1.DEFAULT_INITIAL_VERSION], [childName, childVersion],] = parseGoModGraphLine(line);
        const parentPkg = { name: parentName, version: parentVersion };
        const childPkg = { name: childName, version: childVersion || types_1.DEFAULT_INITIAL_VERSION };
        const parentNodeId = parentName === rootPkgInfo.name ? types_1.DEFAULT_ROOT_NODE_NAME : `${parentName}@${parentVersion}`;
        const childNodeId = `${childPkg.name}@${childPkg.version}`;
        if (parentPkg.name !== rootPkgInfo.name) {
            depGraph.addPkgNode(parentPkg, parentNodeId);
        }
        depGraph.addPkgNode(childPkg, childNodeId);
        depGraph.connectDep(parentNodeId, childNodeId);
    }
    return depGraph.build();
}
exports.parseGoModGraph = parseGoModGraph;
//# sourceMappingURL=gomod-graph-parser.js.map